==> ews-javascript-api-0.1.3.tgz: package/js/PropertyDefinitions/PermissionSetPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var FolderPermissionCollection_1 = require("../ComplexProperties/FolderPermissionCollection");
var ComplexPropertyDefinitionBase_1 = require("./ComplexPropertyDefinitionBase");
var EwsLogging_1 = require("../Core/EwsLogging");
var PermissionSetPropertyDefinition = (function (_super) {
    __extends(PermissionSetPropertyDefinition, _super);
    function PermissionSetPropertyDefinition(propertyName, xmlElementName, version, uri, flags) {
        _super.call(this, propertyName, xmlElementName, version, uri, flags);
    }
    Object.defineProperty(PermissionSetPropertyDefinition.prototype, "Type", {
        get: function () {
            return undefined; // new Type("FolderPermissionCollection");
        },
        enumerable: true,
        configurable: true
    });
    PermissionSetPropertyDefinition.prototype.CreatePropertyInstance = function (owner) {
        var folder = owner.IsFolderInstance() ? owner : null; // ((owner instanceof Folder) ? <Folder>owner : null);
        EwsLogging_1.EwsLogging.Assert(folder !== null, "PermissionCollectionPropertyDefinition.CreatePropertyInstance", "The owner parameter is not of type Folder or a derived class.");
        return new FolderPermissionCollection_1.FolderPermissionCollection(folder);
    };
    return PermissionSetPropertyDefinition;
})(ComplexPropertyDefinitionBase_1.ComplexPropertyDefinitionBase);
exports.PermissionSetPropertyDefinition = PermissionSetPropertyDefinition;

==> ews-javascript-api-0.1.6.tgz: package/js/PropertyDefinitions/PermissionSetPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var FolderPermissionCollection_1 = require("../ComplexProperties/FolderPermissionCollection");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var EwsLogging_1 = require("../Core/EwsLogging");
var ComplexPropertyDefinitionBase_1 = require("./ComplexPropertyDefinitionBase");
var PermissionSetPropertyDefinition = (function (_super) {
    __extends(PermissionSetPropertyDefinition, _super);
    function PermissionSetPropertyDefinition(propertyName, xmlElementName, version, uri, flags) {
        _super.call(this, propertyName, xmlElementName, version, uri, flags);
    }
    Object.defineProperty(PermissionSetPropertyDefinition.prototype, "Type", {
        get: function () {
            return undefined; // new Type("FolderPermissionCollection");
        },
        enumerable: true,
        configurable: true
    });
    PermissionSetPropertyDefinition.prototype.CreatePropertyInstance = function (owner) {
        var folder = owner.InstanceType === XmlElementNames_1.XmlElementNames.Folder ? owner : null; // ((owner instanceof Folder) ? <Folder>owner : null);
        EwsLogging_1.EwsLogging.Assert(folder !== null, "PermissionCollectionPropertyDefinition.CreatePropertyInstance", "The owner parameter is not of type Folder or a derived class.");
        return new FolderPermissionCollection_1.FolderPermissionCollection(folder);
    };
    return PermissionSetPropertyDefinition;
})(ComplexPropertyDefinitionBase_1.ComplexPropertyDefinitionBase);
exports.PermissionSetPropertyDefinition = PermissionSetPropertyDefinition;
